pub struct DistanceMatrix {
pub rows: usize,
pub columns: usize,
pub data: Vec<i64>,
}Fields
rows: usizecolumns: usizedata: Vec<i64>Implementations
Sourceimpl DistanceMatrix
Helper struct to handle the distance matrix and allow for repeated tiles.
impl DistanceMatrix
Helper struct to handle the distance matrix and allow for repeated tiles.
Sourceimpl DistanceMatrix
impl DistanceMatrix
Sourcepub fn assignments<S: Solve>(
&self,
solver: &mut S,
) -> Result<Vec<usize>, PhomoError>
pub fn assignments<S: Solve>( &self, solver: &mut S, ) -> Result<Vec<usize>, PhomoError>
Solve the linear sum assignment problem using the provided solver.
Arguments
solver: The solver to use to solve the assignment problem. Seephomo::solversfor structs which implement this trait.
Errors
PhomoError::SolverError: An error occurred while solving the assignment problem.