Mosaic

Struct Mosaic 

pub struct Mosaic {
    pub master: Master,
    pub tiles: Vec<RgbImage>,
    pub grid_size: (u32, u32),
}

Fields

master: Master

The Master image to reconstruct.

tiles: Vec<RgbImage>

The tile images to use to reconstruct the Master image. The tile images should be the same size as the Master::cell_size. There should also be at least Master::cells.len() tiles.

grid_size: (u32, u32)

The number of cells horizontally and vertically in the mosaic.

Implementations

Source

impl Mosaic

Represents a photo mosaic.

pub fn from_file_and_dir<P: AsRef<Path>, Q: AsRef<Path>>( master_file: P, tile_dir: Q, grid_size: (u32, u32), ) -> Result<Self, PhomoError>

Construct a Mosaic from a master image file and a directory of tile images.

Arguments
  • master_file: The path to the master image file.
  • tile_dir: The path to the directory containing the tile images.
  • grid_size: The grid size of the mosaic, the number of cells horizontally and vertically.
Errors
pub fn from_images( master_img: RgbImage, tiles: Vec<RgbImage>, grid_size: (u32, u32), ) -> Result<Self, PhomoError>

Construct a Mosaic from RgbImage buffers of the master images and the tile images.

Arguments
  • master_img: The master image buffer.
  • tiles: The tile image buffers.
  • grid_size: The grid size of the mosaic, the number of cells horizontally and vertically.
  • max_tile_occurrences: The maximum number of times a tile can be repeated in the mosaic. Should be greater than 0.
Errors
pub fn new( master: Master, tiles: Vec<RgbImage>, grid_size: (u32, u32), ) -> Result<Self, PhomoError>

Create a new Mosaic from the provided Master and tiles.

Arguments
  • master: The master.
  • tiles: The tile image buffers.
  • grid_size: The grid size of the mosaic, the number of cells horizontally and vertically.
Errors
pub fn distance_matrix(&self) -> DistanceMatrix

Compute the DistanceMatrix between the tiles and the master cells, using the norm_l1 metric.

To use a different distance metric, use the distance_matrix_with_metric method.

The row index is the cell index and the column index is the tile index.

pub fn distance_matrix_with_metric( &self, metric: fn(&RgbImage, &RgbImage) -> i64, ) -> DistanceMatrix

Compute the DistanceMatrix between the tiles and the master cells using the provided metric function. See phomo::metrics for implemented distance metrics.

The row index is the cell index and the column index is the tile index.

pub fn render(&self, assignments: Vec<usize>) -> Result<RgbImage, PhomoError>

Render the photo mosaic image using the provided tile assignments.

Arguments
  • assignments: The tile index assigned to each master cell. The length of the assignments should be equal to the number of master cells. The tile index should be less than the number of tiles.
Errors
pub fn build( &self, distance_matrix: DistanceMatrix, config: SolverConfig, ) -> Result<RgbImage, PhomoError>

Compute the tile to master cell assignments using the Hungarian solver algorithm, and build the photo mosaic image.

Errors
pub fn build_with_solver<S: Solve>( &self, distance_matrix: DistanceMatrix, solver: S, ) -> Result<RgbImage, PhomoError>

Compute the tile to master cell assignments using the provided solver algorithm, and build the photo mosaic image. See phomo::solvers for implemented solvers.

Arguments
  • distance_matrix: The distance matrix between the master image and the tiles.
  • solver: The solver algorithm to use for the assignment problem.
Errors
Source

impl Mosaic

pub fn build_blueprint( &self, distance_matrix: DistanceMatrix, config: SolverConfig, ) -> Result<Blueprint, PhomoError>

Available on crate feature blueprint only.

Compute the tile to master cell assignments, and construct a Blueprint of the mosaic image.

Errors
pub fn build_blueprint_with_solver<S: Solve>( &self, distance_matrix: DistanceMatrix, solver: S, ) -> Result<Blueprint, PhomoError>

Available on crate feature blueprint only.

Compute the tile to master cell assignments using the provided solver algorithm, and construct a Blueprint of the mosaic image. See phomo::solvers for implemented solvers.

Arguments:
  • distance_matrix: The distance matrix between the master image and the tiles.
  • solver: The solver algorithm to use for the assignment problem.
Errors